@@ -2,7 +2,7 @@
  * libdicom by Tony Voet *
  *************************/
 /*
- * $Id: basic.c,v 1.23 2005/12/02 23:06:44 enlf Exp $
+ * $Id: basic.c,v 1.26 2006/12/08 21:50:24 enlf Exp $
  */
 
 #include <stdio.h>
@@ -45,8 +45,8 @@ static enum
 syntax,endian,filesyntax,pixelsyntax,encapsyntax;
 
 #if MEDCON_INTEGRATED
-/* eNlf: routine for setting the stream from outside the library    */
-/* eNlf: in MedCon this library doesn't have to open or close steam */         
+/* eNlf: routine for setting the stream from outside the library     */
+/* eNlf: in MedCon this library doesn't have to open or close stream */         
 /********
  * init *
  ********/
@@ -1032,6 +1032,11 @@ int mdc_dicom_decompress(SINGLE *s, ELEMENT *e)
           return(-1);
         break;
     case COMPRESSED_LOSSLESS:
+        if (s->w > 4096) {
+          dicom_log(WARNING,"LJPG compiled with 4096-wide image limit");
+          dicom_log(WARNING,"Check out 'jpegutil.c' file to increase");
+          return(-2);
+        }
         if (mdc_dicom_decomp_ljpg(stream,(U16*)e->value.OB,e->length
                                         ,(unsigned)s->alloc*s->samples))
           return(-2);
