@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-acr.h,v 1.26 2005/12/16 23:33:04 enlf Exp $ 
+/* $Id: m-acr.h,v 1.28 2006/12/03 22:49:03 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -112,7 +112,7 @@ void MdcPrintTag(FILEINFO *fi, MDC_ACR_TAG *tag, char *fmt, ...);
 int MdcGetStrVM(char *dest,char *src, Uint32 nr);
 void MdcDicomInitStuff(MDC_DICOM_STUFF_T *dicom);
 void MdcDicomCheckVect(MDC_DICOM_STUFF_T *dicom, MDC_ACR_TAG *tag, int VECTOR);
-Uint32 MdcDicomNrOfVect(MDC_DICOM_STUFF_T *dicom, Int16 nr, int VECTOR);
+Uint32 MdcDicomNrOfVect(MDC_DICOM_STUFF_T *dicom, Uint16 nr, int VECTOR);
 int MdcDicomDoAcqData(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom);
 int MdcDicomSOPClass(char *sopclass);
 int MdcGetHHMMSS(char *time, Int16 *hour, Int16 *minute, Int16 *second);
