@@ -39,11 +39,11 @@
  *                MdcUnpackBIT12()        - Unpack 12 bit into Uint16      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-algori.c,v 1.77 2005/12/16 23:34:46 enlf Exp $ 
+/* $Id: m-algori.c,v 1.80 2006/03/17 23:33:44 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -531,6 +531,9 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
      id->bits = MdcType2Bits(id->type);
 
      if (id->type != fi->image[0].type) fi->diff_type = MDC_YES;
+     if (id->quant_scale != fi->image[0].quant_scale) fi->diff_scale = MDC_YES;
+     if (id->calibr_fctr != fi->image[0].calibr_fctr) fi->diff_scale = MDC_YES;
+     if (id->intercept   != fi->image[0].intercept  ) fi->diff_scale = MDC_YES;
      if (j == 0) {
        fi->mwidth  = id->width;
        fi->mheight = id->height;
@@ -982,7 +985,7 @@ char *MdcImagesPixelFiddle(FILEINFO *fi)
   }
 
   /* warn about fixed values */
-  if (FixWarn) MdcPrntWarn("Fixed image(s) with bad floats (= set to zero)");
+  if (FixWarn) MdcPrntWarn("Fixed pixels with bad float value (= set to zero)");
 
   /* don't forget to fill in the min/max values for the last frame group */
   for (t=j - fi->dim[3]; t<j ; t++) {        
@@ -1194,6 +1197,11 @@ Uint8 *MdcGetResizedImage(FILEINFO *fi,Uint8 *buffer,int type,Uint32 img)
   double pval;
   Uint8 *maxbuf, *obuf, *ibuf=buffer;
 
+  if (id->type == COLRGB) {
+    MdcPrntWarn("Resizing true color RGB images unsupported");
+    return(NULL);
+  }
+
   if (id->rescaled) {
     pval = id->rescaled_min;
   }else{
