@@ -17,11 +17,11 @@
  *                MdcGetSpmOpt()           - Get specific SPM options      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-anlz.c,v 1.75 2005/11/17 22:28:32 enlf Exp $
+/* $Id: m-anlz.c,v 1.79 2006/03/18 00:09:10 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -396,7 +396,7 @@ const char *MdcReadANLZ(FILEINFO *fi)
   /* read the image file */
   MdcCloseFile(fi->ifp);
   MdcMergePath(fi->ipath,fi->idir,fi->ifname);
-  MdcNewExt(fi->ipath,NULL,"img");
+  MdcSetExt(fi->ipath,"img");
 
   /* check for compressed image file */
   if (MdcFileExists(fi->ipath) == MDC_NO) {
@@ -515,7 +515,7 @@ const char *MdcReadANLZ(FILEINFO *fi)
 
   MdcCloseFile(fi->ifp);
 
-  /* check some finale FILEINFO entries */
+  /* check some final FILEINFO entries */
   if (fi->dim[4] > 1) {
     fi->acquisition_type = MDC_ACQUISITION_DYNAMIC;
     /* fill in dynamic data struct */
@@ -572,6 +572,7 @@ int MdcWriteHeaderKey(FILEINFO *fi)
 int MdcWriteImageDimension(FILEINFO *fi, MDC_SPMOPT *opt)
 {
   MDC_ANLZ_IMAGE_DIMS imd;
+  float glmax, glmin;
   int i;
 
   memset(&imd,0,MDC_ANLZ_IMD_SIZE);
@@ -658,29 +659,31 @@ int MdcWriteImageDimension(FILEINFO *fi, MDC_SPMOPT *opt)
     }
   }
 
-  if (MDC_FORCE_INT != MDC_NO) {
-    switch (MDC_FORCE_INT) { 
-     case BIT8_U : imd.glmin = 0; imd.glmax = MDC_MAX_BIT8_U;  break;
-     case BIT16_S: imd.glmin = 0; imd.glmax = MDC_MAX_BIT16_S; break;
-     default     : imd.glmin = 0; imd.glmax = MDC_MAX_BIT16_S;
-    }
-  }else if (!(MDC_QUANTIFY || MDC_CALIBRATE)) {
-    imd.glmin = (Int32) fi->glmin;
-    imd.glmax = (Int32) fi->glmax;
-  }else{
-    if (MDC_ANLZ_SPM == MDC_YES) {
-      if (MDC_NEGATIVE == MDC_YES) {
-        imd.glmin = -(MDC_MAX_BIT16_S + 1); 
-      }else{ 
-        imd.glmin = 0;
-      }
-      imd.glmax = MDC_MAX_BIT16_S;
-    }else{  /* a little useless to cast a float value */
-      imd.glmin = (Int32) fi->qglmin;
-      imd.glmax = (Int32) fi->qglmax;
-    }
+  /* find and set max/min values */
+  for (i = 0; i < fi->number; i++) {
+     IMG_DATA *id = &fi->image[i];
+     if (id->rescaled == MDC_YES) {
+       if (i == 0) { /* init values */
+         glmax = id->rescaled_max;
+         glmin = id->rescaled_min; 
+       }else{        /* get max/min */
+         glmax = (id->rescaled_max > glmax) ? id->rescaled_max : glmax;
+         glmin = (id->rescaled_min < glmin) ? id->rescaled_min : glmin;
+       }
+     }else{
+       if (i == 0) { /* init values */
+         glmax = id->max;
+         glmin = id->min;
+       }else{        /* get max/min */
+         glmax = (id->max > glmax) ? id->max : glmax;
+         glmin = (id->min < glmin) ? id->min : glmin;
+       }
+     }
   }
 
+  imd.glmax = (Int32) glmax;
+  imd.glmin = (Int32) glmin;
+   
   imd.avw_cal_max = fi->qglmax;
   imd.avw_cal_min = fi->qglmin;
 
