@@ -23,11 +23,11 @@
  * Credits      :                                                          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-conc.c,v 1.83 2005/11/17 22:28:32 enlf Exp $
+/* $Id: m-conc.c,v 1.85 2006/08/29 22:26:30 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -2032,7 +2032,7 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   BED_DATA * bd = NULL;
   GATED_DATA * gd = NULL;
   int i_bed, i_gate, i_frame, i_plane;
-  float calibration_factor, fstart, fduration;
+  float calibration_factor, fstart, fduration, slice_width;
   Int32 high_file_pointer, low_file_pointer;
   Uint32 img, fnr;
   Int16 pixtype;
@@ -2129,9 +2129,13 @@ const char *MdcSaveHeaderCONC(FILEINFO *fi)
   fprintf(fi->ofp, "#  Note: isotope branching fraction is included in the calibration fraction\n%s %g\n" 
                 , MdcConcHdrValueNames[MDC_CONC_HDR_ISOTOPE_BRANCHING_FRACTION]
                 , 1.0);
+  slice_width = fi->pixdim[3];
+#ifdef MDC_USE_SLICE_SPACING
+  if (fi->number > 1) slice_width = fi->image[0].slice_spacing;
+#endif
   fprintf(fi->ofp, "#\n%s %g\n"
                 , MdcConcHdrValueNames[MDC_CONC_HDR_AXIAL_CRYSTAL_PITCH]
-                , 2.0*fi->pixdim[3]/10.0);
+                , 2.0*slice_width/10.0);
 
   pixtype = conc_save_type(fi);
 
