@@ -11,11 +11,11 @@
  *                MdcDebugPrint()    - Print MDC_MY_DEBUG info             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-debug.c,v 1.58 2005/12/18 09:50:13 enlf Exp $
+/* $Id: m-debug.c,v 1.61 2006/12/05 22:47:44 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -98,6 +98,8 @@ void MdcPrintFI(FILEINFO *fi)
   MdcPrintYesNo(fi->diff_type);
   MdcPrntScrn("diff_size          : %d ",fi->diff_size);
   MdcPrintYesNo(fi->diff_size);
+  MdcPrntScrn("diff_scale         : %d ",fi->diff_scale);
+  MdcPrintYesNo(fi->diff_scale);
   MdcPrntScrn("number             : %u\n",fi->number);
   MdcPrntScrn("mwidth             : %u\n",fi->mwidth);
   MdcPrntScrn("mheight            : %u\n",fi->mheight);
@@ -372,6 +374,49 @@ void MdcPrintFI(FILEINFO *fi)
      }
  }
 
+ /* DICOM MOD */
+ if (fi->mod != NULL) {
+   GN_INFO *gn = &fi->mod->gn_info;
+   MR_INFO *mr = &fi->mod->mr_info;
+
+   MdcPrntScrn("\n");
+   MdcPrintLine('-',MDC_HALF_LENGTH);
+   MdcPrntScrn("FILEINFO - DICOM General Info\n");
+   MdcPrintLine('-',MDC_HALF_LENGTH); 
+
+   MdcPrntScrn("study_date            : %s\n",gn->study_date);
+   MdcPrntScrn("study_time            : %s\n",gn->study_time);
+   MdcPrntScrn("series_date           : %s\n",gn->series_date);
+   MdcPrntScrn("series_time           : %s\n",gn->series_time);
+   MdcPrntScrn("acquisition_date      : %s\n",gn->acquisition_date);
+   MdcPrntScrn("acquisition_time      : %s\n",gn->acquisition_time);
+   MdcPrntScrn("image_date            : %s\n",gn->image_date);
+   MdcPrntScrn("image_time            : %s\n",gn->image_time);
+
+   switch (fi->modality) {
+     case M_MR:
+         MdcPrintLine('-',MDC_HALF_LENGTH);
+         MdcPrntScrn("FILEINFO - DICOM MR Modality Info\n");
+         MdcPrintLine('-',MDC_HALF_LENGTH); 
+         MdcPrntScrn("repetition_time       : %f\n",mr->repetition_time);
+         MdcPrntScrn("echo_time             : %g\n",mr->echo_time);
+         MdcPrntScrn("inversion_time        : %g\n",mr->inversion_time);
+         MdcPrntScrn("num_averages          : %g\n",mr->num_averages);
+         MdcPrntScrn("imaging_freq          : %f\n",mr->imaging_freq);
+         MdcPrntScrn("pixel_bandwidth       : %g\n",mr->pixel_bandwidth);
+         MdcPrntScrn("flip_angle            : %g\n",mr->flip_angle);
+         MdcPrntScrn("dbdt                  : %g\n",mr->dbdt);
+         MdcPrntScrn("transducer_freq       : %u\n",mr->transducer_freq);
+         MdcPrntScrn("transducer_type       : %s\n",mr->transducer_type);
+         MdcPrntScrn("pulse_repetition_freq : %u\n",mr->pulse_repetition_freq);
+         MdcPrntScrn("pulse_seq_name        : %s\n",mr->pulse_seq_name);
+         MdcPrntScrn("steady_state_pulse_seq: %s\n",mr->steady_state_pulse_seq);
+         MdcPrntScrn("slab_thickness        : %g\n",mr->slab_thickness);
+         MdcPrntScrn("sampling_freq         : %g\n",mr->sampling_freq);
+         break;
+   }
+ }
+
 }
 
 
