@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-defs.h,v 1.48 2005/11/17 22:28:32 enlf Exp $
+/* $Id: m-defs.h,v 1.53 2006/08/29 22:23:32 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -49,11 +49,11 @@
 #define MDC_NEWLINE "\n"
 #endif
 
-/* Use slice_spacing instead of slice_width which  */
-/* results in slice gaps/overlaps of zero. Very    */
-/* neat for formats without slice_spacing param.   */
-/* better for volumes <=> losing true slice_width  */
-/* Comment out following line when not wanted.     */ 
+/* For output formats without slice_spacing key, it is prefered
+ * to use slice_spacing as the slice_width parameter, and thus
+ * virtually "eliminating" any gaps/overlaps between those sices.
+ * If not wanted, comment out following define line.
+ */
 #define MDC_USE_SLICE_SPACING 1
 
 
@@ -90,7 +90,7 @@
 
 
 /****************************************************************************
-                              D E F I N E S 
+                              D E F I N E S
 ****************************************************************************/
 
 #define MDC_ONE           1
@@ -99,7 +99,7 @@
 #define MDC_FALSE        (0)
 #define MDC_TRUE         (!MDC_FALSE)
 
-#define MDC_UNKNOWN      MDC_ZERO 
+#define MDC_UNKNOWN      MDC_ZERO
 
 #define MDC_LITTLE_ENDIAN  MDC_ONE
 #define MDC_BIG_ENDIAN     MDC_ZERO
@@ -113,7 +113,7 @@
 #define MDC_MAX_PATH  256
 #define MDC_MAX_LIST  256
 
-#define MDC_YES    MDC_ONE 
+#define MDC_YES    MDC_ONE
 #define MDC_NO     MDC_ZERO
 
 #define MDC_ARG_FILE    0
@@ -123,6 +123,9 @@
 #define MDC_FILES     0
 #define MDC_CONVS     1
 
+/* precision */
+#define MDC_FLT_EPSILON 1.1920928955078125e-07
+
 /* passess */
 #define MDC_PASS0     0
 #define MDC_PASS1     1
@@ -142,7 +145,7 @@
 #define MDC_MAP_COMBINED  4        /* combined  colormap */
 #define MDC_MAP_HOTMETAL  5        /* hotmetal  colormap */
 
-#define MDC_MAP_LOADED    6        /* loaded    colormap */ 
+#define MDC_MAP_LOADED    6        /* loaded    colormap */
 
 /* supported color modes */
 #define MDC_COLOR_INDEXED 0        /* 256 indexed colors */
@@ -153,18 +156,19 @@
 #define MDC_FRMT_NONE    MDC_FRMT_BAD
 #define MDC_FRMT_RAW     1
 #define MDC_FRMT_ASCII   2
-#define MDC_FRMT_GIF     3 
-#define MDC_FRMT_ACR     4 
-#define MDC_FRMT_INW     5 
+#define MDC_FRMT_GIF     3
+#define MDC_FRMT_ACR     4
+#define MDC_FRMT_INW     5
 #define MDC_FRMT_ECAT6   6
-#define MDC_FRMT_ECAT7   7 
-#define MDC_FRMT_INTF    8 
-#define MDC_FRMT_ANLZ    9 
+#define MDC_FRMT_ECAT7   7
+#define MDC_FRMT_INTF    8
+#define MDC_FRMT_ANLZ    9
 #define MDC_FRMT_DICM    10
 #define MDC_FRMT_PNG     11
 #define MDC_FRMT_CONC    12
+#define MDC_FRMT_NIFTI   13
 
-#define MDC_MAX_FRMTS    13        /* total+1 conversion formats supported */
+#define MDC_MAX_FRMTS    14        /* total+1 conversion formats supported */
 
 /* acquisition types */                      /*  InterFile and DICOM   */
 #define MDC_ACQUISITION_UNKNOWN    MDC_ZERO  /* unknown = static       */
@@ -258,7 +262,7 @@
 #define MDC_MAX_FILES 10000 /* maximum files handled        */
                             /* 3-char prefix: 34696 uniques */
 
-#define MDC_MAXSTR      35  /* max length of strings        */ 
+#define MDC_MAXSTR      35  /* max length of strings        */
 
 #define MDC_BUF_ITMS    10  /* realloc per BUF_ITMS items   */
 
