@@ -18,11 +18,11 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.170 2005/12/16 23:43:26 enlf Exp $
+/* $Id: m-dicm.c,v 1.173 2006/12/05 22:41:23 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -180,9 +180,6 @@ char *MdcDicomHandleImages(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom, IMAGE *image,
   IMG_DATA *id;
   Uint32 img=0, i, f, bytes, t;
   Uint8 *pdata = NULL;
-  double rs, ri;
-  double wc, ww;
-  char *msg=NULL;
 
   for (img=0, i=0; i<number; i++) {
      pimg = &image[i];
@@ -2308,7 +2305,11 @@ static void mdc_dicom_printinfo(const ELEMENT *e,const char *description)
  
     case LT :
     case ST :
-      MdcGetSafeString(mdcbufr,e->value.LT,e->length,MDC_2KB_OFFSET);
+      if (e->length > 128) {
+        strcpy(mdcbufr,"...");
+      }else{
+        MdcGetSafeString(mdcbufr,e->value.LT,e->length,MDC_2KB_OFFSET);
+      }
       MdcPrntScrn("[%s] ",mdcbufr);
       break;
  
@@ -2325,7 +2326,11 @@ static void mdc_dicom_printinfo(const ELEMENT *e,const char *description)
     case TM :
     case UI :
       len = strlen(e->value.AE[i]);
-      MdcGetSafeString(mdcbufr,e->value.AE[i],len,MDC_2KB_OFFSET);
+      if (len > 128) {
+        strcpy(mdcbufr,"...");
+      }else{
+        MdcGetSafeString(mdcbufr,e->value.AE[i],len,MDC_2KB_OFFSET);
+      }
       MdcPrntScrn("[%s] ",mdcbufr);
       break;
  
