@@ -26,6 +26,7 @@
  *                MdcWriteDoublePixel() - Write single pixel double input  *
  *                MdcGetFname()         - Get filename                     *
  *                MdcGetExtension()     - Get filename original extension  *
+ *                MdcSetExt()           - Set filename extension           *
  *                MdcNewExt()           - Create filename extension        *
  *                MdcPrefix()           - Create filename prefix           * 
  *                MdcGetPrefixNr()      - Get proper filename prefix       *
@@ -46,11 +47,11 @@
  *                MdcGetHeartRate()     - Get heart rate from gated data   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-files.c,v 1.96 2005/12/16 23:39:03 enlf Exp $ 
+/* $Id: m-files.c,v 1.101 2006/03/15 22:52:26 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -101,8 +102,15 @@ int MdcOpenFile(FILEINFO *fi, char *path)
   if (MDC_FILE_STDIN == MDC_NO) {
     if ( (ctype = MdcWhichCompression(path)) != MDC_NO ) {
       if ((MdcDecompressFile(path)) != MDC_OK) {
+
         MdcPrntWarn("Decompression failed");
-        return(MDC_BAD_OPEN);
+
+        /* no longer quit, because NIFTI */
+        /* can read .gz files directly   */
+        /* return(MDC_BAD_OPEN); */
+       
+        /* prevent unwanted unlink later */ 
+        ctype = MDC_NO;
       }
     }
   }else{
@@ -188,6 +196,9 @@ int MdcReadFile(FILEINFO *fi, int filenr, char *(*ReadFunc)(FILEINFO *fi))
 #endif
 #if MDC_INCLUDE_CONC
     case MDC_FRMT_CONC: msg=MdcReadCONC(fi); break;
+#endif
+#if MDC_INCLUDE_NIFTI
+    case MDC_FRMT_NIFTI: msg=MdcReadNIFTI(fi); break;
 #endif
     default:
       if (ReadFunc != NULL) {
@@ -316,6 +327,9 @@ int MdcWriteFile(FILEINFO *fi, int format, int prefixnr, char *(*WriteFunc)())
 #endif
 #if MDC_INCLUDE_CONC
     case MDC_FRMT_CONC : msg=MdcWriteCONC(fi); break;
+#endif
+#if MDC_INCLUDE_NIFTI
+    case MDC_FRMT_NIFTI: msg=MdcWriteNIFTI(fi); break;
 #endif
     default:
       if (WriteFunc != NULL) {
@@ -383,6 +397,9 @@ int MdcLoadFile(FILEINFO *fi)
 #endif
 #if MDC_INCLUDE_CONC
     case MDC_FRMT_CONC: msg=MdcLoadCONC(fi); break;
+#endif
+#if MDC_INCLUDE_NIFTI
+    case MDC_FRMT_NIFTI: msg=MdcReadNIFTI(fi); break;
 #endif
     default:
       MdcPrntWarn("Loading: unsupported format");
@@ -445,6 +462,9 @@ int MdcSaveFile(FILEINFO *fi, int format, int prefixnr)
 #endif
 #if MDC_INCLUDE_CONC
     case MDC_FRMT_CONC : msg=MdcSaveCONC(fi); break;
+#endif
+#if MDC_INCLUDE_NIFTI
+    case MDC_FRMT_NIFTI: msg=MdcWriteNIFTI(fi); break;
 #endif
     default:
       MdcPrntWarn("Writing: Unsupported format");
@@ -518,6 +538,9 @@ int MdcLoadPlane(FILEINFO *fi, Uint32 img)
 #endif
 #if MDC_INCLUDE_CONC
     case MDC_FRMT_CONC: msg=MdcLoadPlaneCONC(fi, (signed)img); break;
+#endif
+#if MDC_INCLUDE_NIFTI
+    case MDC_FRMT_NIFTI: /* msg=MdcLoadPlaneNIFTI(fi, img); */ break;
 #endif
     default:
       MdcPrntWarn("Loading plane %d: unsupported format",img);
@@ -557,6 +580,9 @@ int MdcDecompressFile(char *path)
 
     if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_END,0.,NULL);
 
+    /* no overwrite, restore orig path */
+    *ext = '.';
+
     return(MDC_BAD_CODE);
   }
 
@@ -564,8 +590,12 @@ int MdcDecompressFile(char *path)
 
     if (MDC_PROGRESS) MdcProgress(MDC_PROGRESS_END,0.,NULL);
 
-    unlink(path); return(MDC_BAD_CODE);
+    unlink(path);
 
+    /* no gunzip? restore orig path */
+    *ext = '.';
+    
+    return(MDC_BAD_CODE);
   }
 
   return(MDC_OK);
@@ -628,7 +658,10 @@ int MdcGetFrmt(FILEINFO *fi)
 
   if (MDC_INTERACTIVE) { fi->iformat = MDC_FRMT_RAW; return(MDC_FRMT_RAW); }
 
-  for (i=3; i<MDC_MAX_FRMTS; i++) {
+  for (i=MDC_MAX_FRMTS-1;i>=3; i--) {
+
+    /* MARK: checks reversed; NIFTI must come before ANLZ */
+    /* otherwise MdcReadANLZ() would handle NIFTI files   */
    
     switch (i) {
 
@@ -660,6 +693,9 @@ int MdcGetFrmt(FILEINFO *fi)
 #endif
 #if MDC_INCLUDE_CONC
      case MDC_FRMT_CONC:  format = MdcCheckCONC(fi); break;
+#endif
+#if MDC_INCLUDE_NIFTI
+     case MDC_FRMT_NIFTI: format = MdcCheckNIFTI(fi); break;
 #endif
     }
 
@@ -924,6 +960,22 @@ char *MdcGetExtension(char path[])
 
 } 
 
+void MdcSetExt(char path[], char *ext)
+{
+  char *p;
+
+  if (path == NULL) return;
+
+  if (ext  == NULL) return;  
+
+  p=(char *)strrchr(path,'.');
+
+  if ( p != NULL )  *p = '\0';
+
+  strcat(path,".");
+  strcat(path,ext);
+}
+
 void MdcNewExt(char dest[], char *src, char *ext)
 {
   char *p, *s;
@@ -948,13 +1000,7 @@ void MdcNewExt(char dest[], char *src, char *ext)
     if ((src != NULL) && (src[0] != '\0'))  strcat(dest,src);
   }
 
-  p=(char *)strrchr(dest,'.');
-
-  if ( p != NULL )  *p = '\0';
-
-  strcat(dest,".");
-  strcat(dest,ext);
-
+  MdcSetExt(dest,ext);
 } 
 
 /* create a prefix of the form: 000 ...  ... 999,A00................ZZZ
@@ -1147,6 +1193,9 @@ void MdcDefaultName(FILEINFO *fi, int format, char dest[], char *src)
 #endif
 #if MDC_INCLUDE_CONC
    case MDC_FRMT_CONC : MdcNewName(dest,src,FrmtExt[MDC_FRMT_CONC]);   break;
+#endif
+#if MDC_INCLUDE_NIFTI
+   case MDC_FRMT_NIFTI: MdcNewName(dest,src,FrmtExt[MDC_FRMT_NIFTI]);  break;
 #endif
    default            : MdcNewName(dest,src,FrmtExt[MDC_FRMT_NONE]);   break; 
   } 
