@@ -14,11 +14,11 @@
  *                MdcHandleArgs()         - Handle the arguments           *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-getopt.c,v 1.127 2005/12/17 13:56:34 enlf Exp $
+/* $Id: m-getopt.c,v 1.130 2006/03/01 23:21:59 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -117,6 +117,11 @@ void MdcPrintGlobalOptions(void)
                                         FrmtString[MDC_FRMT_INW],
                                         FrmtExt[MDC_FRMT_INW]);
 #endif
+#if MDC_INCLUDE_NIFTI
+  MdcPrntScrn("\t\t\"nifti\" = %s (.%s)\n",
+                                        FrmtString[MDC_FRMT_NIFTI],
+                                        FrmtExt[MDC_FRMT_NIFTI]);
+#endif
 #if MDC_INCLUDE_PNG
   MdcPrntScrn("\t\t\"png\"   = %s (.%s)\n",
                                         FrmtString[MDC_FRMT_PNG],
@@ -318,7 +323,7 @@ void MdcPrintShortInfo(void)
   }
     MdcPrntScrn(" Medical Image Conversion Utility\n");
     MdcPrntScrn("(X)MedCon %s\n",MdcGetLibShortVersion());
-    MdcPrntScrn("Copyright (C) 1997-2005 by Erik Nolf\n\n");
+    MdcPrntScrn("Copyright (C) 1997-2006 by Erik Nolf\n\n");
 
   if (XMDC_GUI == MDC_YES) {
     MdcPrntScrn("Try \'xmedcon --help\' for more information.\n\n");
@@ -822,6 +827,11 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
              convs[MDC_FRMT_PNG]+=1;  total[MDC_CONVS]+=1;
          }else
 #endif
+#if MDC_INCLUDE_NIFTI
+         if ( strcasecmp(argv[a],"nifti") == 0) {
+             convs[MDC_FRMT_NIFTI]+=1;  total[MDC_CONVS]+=1;
+         }else
+#endif
 #endif
          if ( strcasecmp(argv[a],"-") == 0) {
            MDC_FILE_STDOUT = MDC_YES;
@@ -896,6 +906,11 @@ int MdcHandleArgs(FILEINFO *fi, int argc, char *argv[], int MAXFILES)
              DO_STDIN = MDC_YES; MDC_FRMT_INPUT = MDC_FRMT_PNG;
            }else
 #endif
+#if MDC_INCLUDE_NIFTI
+           if ( strcasecmp(argv[a],"nifti") == 0) {
+             DO_STDIN = MDC_YES; MDC_FRMT_INPUT = MDC_FRMT_NIFTI;
+           }else
+#endif
            
              { DO_STDIN = MDC_NO;  MDC_FRMT_INPUT = MDC_FRMT_NONE; }
 
