@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.c,v 1.68 2005/12/16 23:42:33 enlf Exp $
+/* $Id: m-global.c,v 1.71 2006/03/01 23:21:59 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -84,7 +84,8 @@ char FrmtString[MDC_MAX_FRMTS][15]= {
     "Analyze      ",    /* MDC_FRMT_ANLZ  */
     "DICOM        ",    /* MDC_FRMT_DICM  */
     "PNG          ",    /* MDC_FRMT_PNG   */
-    "Concorde/uPET"     /* MDC_FRMT_CONC  */
+    "Concorde/uPET",    /* MDC_FRMT_CONC  */
+    "NIfTI        "     /* MDC_FRMT_NIFTI */
   /*"............."                       */
 };
 
@@ -101,7 +102,8 @@ char FrmtExt[MDC_MAX_FRMTS][8] = {
     "hdr",    /* MDC_FRMT_ANLZ  */
     "dcm",    /* MDC_FRMT_DICM  */
     "png",    /* MDC_FRMT_PNG   */
-    "img.hdr" /* MDC_FRMT_CONC  */
+    "img.hdr",/* MDC_FRMT_CONC  */
+    "nii"     /* MDC_FRMT_NIFTI */
   /*"..."                       */
 };
 
