@@ -13,11 +13,11 @@
  *                MdcStackFiles()          - Main stack routine            *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-stack.c,v 1.30 2005/11/17 22:28:32 enlf Exp $
+/* $Id: m-stack.c,v 1.36 2006/05/26 22:58:32 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -57,21 +57,22 @@ static int mdc_nrstack=0;
 float MdcGetNormSliceSpacing(IMG_DATA *id1, IMG_DATA *id2)
 {
   /* slice_spacing = sqrt( (x2-x1)^2 + (y2-y1)^2 + (z2-z1)^2 ) */
-  double value;
-  float slice_spacing;
+  float value, slice_spacing;
   float dx, dy, dz;
 
+  slice_spacing = id1->slice_spacing;
+
   dx = id1->image_pos_pat[0] - id2->image_pos_pat[0];
   dy = id1->image_pos_pat[1] - id2->image_pos_pat[1];
   dz = id1->image_pos_pat[2] - id2->image_pos_pat[2];
 
-  value = sqrt((double)(dx*dx + dy*dy + dz*dz));
+  value = (float)sqrt((double)(dx*dx + dy*dy + dz*dz));
 
-  if (value == 0.) {
-    /* missing image_pos_pat[] info */
+  if (fabs(slice_spacing - value) <= MDC_FLT_EPSILON)  {
+    /* insignificant difference, use original header value */
     slice_spacing = id1->slice_spacing;
   }else{
-    /* proper  image_pos_pat[] info */
+    /* significant, use calculated value from image_pos_pat[] info */
     slice_spacing = (float)value;
   }
 
@@ -265,6 +266,12 @@ char *MdcStackSlices(void)
     ofi->image[0].slice_spacing = ofi->image[1].slice_spacing;
   }
 
+  /* if requested, reverse slices */
+  if (MDC_SORT_REVERSE == MDC_YES) {
+    msg = MdcSortReverse(ofi);
+    if (msg != NULL) return(msg); 
+  }
+
   /* write the file */
   if (total[MDC_CONVS] > 0) {
     /* go through conversion formats */
