@@ -37,11 +37,11 @@
  *                MdcCleanUpFI()        - Clean up FILEINFO struct         *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.c,v 1.69 2005/12/16 23:31:55 enlf Exp $ 
+/* $Id: m-structs.c,v 1.72 2006/12/05 22:44:43 enlf Exp $ 
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -300,6 +300,23 @@ void MdcInitMOD(MOD_INFO *mod)
   mod->gn_info.acquisition_time[0]='\0';
   mod->gn_info.image_date[0]='\0';
   mod->gn_info.image_time[0]='\0';
+
+  mod->mr_info.repetition_time=0.;
+  mod->mr_info.echo_time=0.;
+  mod->mr_info.inversion_time=0.;
+  mod->mr_info.num_averages=0.;
+  mod->mr_info.imaging_freq=0.;
+  mod->mr_info.pixel_bandwidth=0.;
+  mod->mr_info.flip_angle=0.;
+  mod->mr_info.dbdt=0.;
+  mod->mr_info.transducer_freq=0;
+  mod->mr_info.transducer_type[0]='\0';
+  mod->mr_info.pulse_repetition_freq=0;
+  mod->mr_info.pulse_seq_name[0]='\0';
+  mod->mr_info.steady_state_pulse_seq[0]='\0';
+  mod->mr_info.slab_thickness=0.;
+  mod->mr_info.sampling_freq=0.;
+
 }
 
 void MdcInitID(IMG_DATA *id)
@@ -403,7 +420,7 @@ void MdcInitFI(FILEINFO *fi, char *path)
    fi->odir = NULL; fi->ofname = NULL;
    fi->image = NULL;
    fi->iformat = MDC_FRMT_NONE; fi->oformat = MDC_FRMT_NONE;
-   fi->diff_type = fi->diff_size = MDC_NO;
+   fi->diff_type = MDC_NO; fi->diff_size = MDC_NO; fi->diff_scale = MDC_NO;
    fi->rawconv = MDC_NO;
    fi->endian = MDC_UNKNOWN;
    fi->modality = M_NM;
@@ -507,6 +524,7 @@ void MdcInitFI(FILEINFO *fi, char *path)
 char *MdcCopyMOD(MOD_INFO *dest, MOD_INFO *src)
 {
   GN_INFO *dgn, *sgn;
+  MR_INFO *dmr, *smr;
 
   dgn = &dest->gn_info; sgn = &src->gn_info;
 
@@ -519,6 +537,24 @@ char *MdcCopyMOD(MOD_INFO *dest, MOD_INFO *src)
   strncpy(dgn->image_date      , sgn->image_date         , MDC_MAXSTR);
   strncpy(dgn->image_time      , sgn->image_time         , MDC_MAXSTR);
 
+  dmr = &dest->mr_info; smr = &src->mr_info;
+
+  dmr->repetition_time = smr->repetition_time;
+  dmr->echo_time       = smr->echo_time;
+  dmr->inversion_time  = smr->inversion_time;
+  dmr->num_averages    = smr->num_averages;
+  dmr->imaging_freq    = smr->imaging_freq;
+  dmr->pixel_bandwidth = smr->pixel_bandwidth;
+  dmr->flip_angle      = smr->flip_angle;
+  dmr->dbdt            = smr->dbdt;
+  dmr->transducer_freq = smr->transducer_freq;
+  strncpy(dmr->transducer_type,smr->transducer_type, MDC_MAXSTR);
+  dmr->pulse_repetition_freq = smr->pulse_repetition_freq;
+  strncpy(dmr->pulse_seq_name, smr->pulse_seq_name,MDC_MAXSTR);
+  strncpy(dmr->steady_state_pulse_seq,smr->steady_state_pulse_seq, MDC_MAXSTR);
+  dmr->slab_thickness  = smr->slab_thickness;
+  dmr->sampling_freq   = smr->sampling_freq;
+
   return(NULL);
 
 }
@@ -703,6 +739,7 @@ char *MdcCopyFI(FILEINFO *dest, FILEINFO *src, int COPY_IMAGES, int KEEP_FILES)
   dest->truncated   = src->truncated;
   dest->diff_type   = src->diff_type;
   dest->diff_size   = src->diff_size;
+  dest->diff_scale  = src->diff_scale;
 /*dest->number      = src->number;*/     /* just see later  */
   dest->mwidth      = src->mwidth;
   dest->mheight     = src->mheight;
