@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-structs.h,v 1.48 2005/12/16 23:31:55 enlf Exp $
+/* $Id: m-structs.h,v 1.51 2006/12/05 22:42:18 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -80,15 +80,28 @@ typedef struct Mod_XA_Info_t  {
 /* specific info MR modality */
 typedef struct Mod_MR_Info_t  {
 
-  int dummy;
+  double repetition_time;
+  double echo_time;
+  double inversion_time;
+  double num_averages;
+  double imaging_freq;
+  double pixel_bandwidth;
+  double flip_angle;
+  double dbdt;
+  Uint32 transducer_freq;
+  char transducer_type[MDC_MAXSTR];
+  Uint32 pulse_repetition_freq;
+  char pulse_seq_name[MDC_MAXSTR];
+  char steady_state_pulse_seq[MDC_MAXSTR];
+  double slab_thickness;
+  double sampling_freq;
 
 } MR_INFO;
 
 typedef struct Modality_Info_t {
 
   GN_INFO gn_info;
-
-  XA_INFO xa_info;
+/*XA_INFO xa_info;*/
   MR_INFO mr_info;
 
 } MOD_INFO;
@@ -229,6 +242,7 @@ typedef struct File_Info_t {
   Int8 truncated;                /* truncated file?        */
   Int8 diff_type;                /* images with diff type? */  
   Int8 diff_size;                /* images with diff size? */
+  Int8 diff_scale;               /* images with diff scale?*/
   Uint32 number;                 /* total number of images */  /* private */
   Uint32 mwidth,mheight;         /* global max dimensions  */
   Int16 bits, type;              /* global bits & datatype */
