@@ -21,11 +21,11 @@
  *                MdcContrastRemap()         - Apply contrast remapping    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-transf.c,v 1.26 2005/12/16 23:37:41 enlf Exp $
+/* $Id: m-transf.c,v 1.28 2006/03/01 23:21:59 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -150,6 +150,8 @@ char *MdcSortReverse(FILEINFO *fi)
   IMG_DATA *id1, *id2, *tmp;
   Uint32 i, size;
 
+  if (fi->number == 1) return(NULL);
+
   size = sizeof(IMG_DATA);
   if ((tmp = (IMG_DATA *)malloc(size)) == NULL)
     return("SortRev - Couldn't malloc IMG_DATA tmp");
@@ -176,6 +178,8 @@ char *MdcSortCineApply(FILEINFO *fi)
   IMG_DATA *tmp;
   Uint32 c, n, i, size;
 
+  if (fi->number == fi->dim[3]) return(NULL);
+
   size = sizeof(IMG_DATA);
   if ((tmp = (IMG_DATA *)malloc(size * fi->number)) == NULL)
     return("SortCine - Couldn't malloc temporary IMG_DATA array");
@@ -200,6 +204,8 @@ char *MdcSortCineUndo(FILEINFO *fi)
   IMG_DATA *tmp;
   Uint32 c, n, i, size;
 
+  if (fi->dim[3] == fi->number) return(NULL);
+
   size = sizeof(IMG_DATA);
   if ((tmp = (IMG_DATA *)malloc(size * fi->number)) == NULL)
     return("SortNoCine - Couldn't malloc temporary IMG_DATA array");
