@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: medcon.h,v 1.29 2005/05/16 07:35:02 enlf Exp $
+/* $Id: medcon.h,v 1.31 2006/03/01 23:21:59 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -102,6 +102,9 @@ extern "C" {
 #if MDC_INCLUDE_PNG
 #  include "m-png.h"
 #endif
+#if MDC_INCLUDE_NIFTI
+#  include "m-nifti.h"
+#endif
 
 #ifdef __cplusplus
 }
