@@ -26,11 +26,11 @@
  *                XMdcRawPredefSelOpen()            - Raw Predef Load      * 
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfilesel.c,v 1.28 2005/05/16 07:35:02 enlf Exp $
+/* $Id: xfilesel.c,v 1.30 2006/03/01 23:21:59 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -333,6 +333,21 @@ void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format)
     gtk_menu_append(GTK_MENU(menu),menuitem);
     gtk_widget_show(menuitem);
 #endif
+#if MDC_INCLUDE_NIFTI
+    if (LOOK && (format == MDC_FRMT_NIFTI)) {
+      XMDC_WRITE_FRMT = MDC_FRMT_NIFTI; LOOK = MDC_NO; selected = item;
+    }
+    format_to_use[MDC_FRMT_NIFTI]=MDC_FRMT_NIFTI;
+    mitem_nr[MDC_FRMT_NIFTI] = item++;
+
+    menuitem = gtk_menu_item_new_with_label(FrmtString[MDC_FRMT_NIFTI]);
+    gtk_signal_connect(GTK_OBJECT(menuitem), "activate",
+                       GTK_SIGNAL_FUNC(XMdcFileSelSaveCallbackFormatMenu),
+                       &format_to_use[MDC_FRMT_NIFTI]);
+
+    gtk_menu_append(GTK_MENU(menu),menuitem);
+    gtk_widget_show(menuitem);
+#endif
 #if MDC_INCLUDE_PNG
     if (LOOK && (format == MDC_FRMT_PNG)) {
       XMDC_WRITE_FRMT = MDC_FRMT_PNG; LOOK = MDC_NO; selected = item;
@@ -349,7 +364,6 @@ void XMdcFileSelSaveCreateFormatMenu(GtkWidget *fs, guint format)
     gtk_widget_show(menuitem);
 #endif
 
-
     if (LOOK) XMdcDisplayFatalErr(MDC_BAD_CODE,"Unexpected format to save");
 
     XMdcFileSelSaveCreateDefaultName(fs);
