@@ -11,11 +11,11 @@
  *                XMdcShowFileInfo()        - Display general file info    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xinfo.c,v 1.55 2005/12/18 09:50:14 enlf Exp $
+/* $Id: xinfo.c,v 1.57 2006/03/01 23:21:59 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -398,6 +398,9 @@ void XMdcShowFileInfo(GtkWidget *widget, gpointer data)
   v = (int)my.fi->diff_size;
   sprintf(xmdcstr,"diff_size   : %d (= %s)\n",v,MdcGetStrYesNo(v));
   gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
+  v = (int)my.fi->diff_scale;
+  sprintf(xmdcstr,"diff_scale  : %d (= %s)\n",v,MdcGetStrYesNo(v));
+  gtk_text_insert(GTK_TEXT(text),NULL,NULL,NULL,xmdcstr,-1);
 
   sprintf(xmdcstr,"\nGeneral Image Information\n"); 
   gtk_text_insert(GTK_TEXT(text),NULL,&Blue,NULL,xmdcstr,-1);
