@@ -12,11 +12,11 @@
  * Functions    : XMdcMenusGetMain()      - Get main menu                  *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xmnuftry.c,v 1.28 2005/05/16 07:35:02 enlf Exp $
+/* $Id: xmnuftry.c,v 1.30 2006/03/01 23:21:59 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2005 by Erik Nolf
+   Copyright (C) 1997-2006 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -87,6 +87,9 @@ static GtkItemFactoryEntry menu_items[] = {
 #if MDC_INCLUDE_INW
   {(char *)"/File/Save As/INW (RUG)", NULL,XMdcFileSelSave,MDC_FRMT_INW,NULL},
 #endif
+#if MDC_INCLUDE_NIFTI
+  {(char *)"/File/Save As/NIFTI",     NULL,XMdcFileSelSave,MDC_FRMT_NIFTI,NULL},
+#endif
 #if MDC_INCLUDE_PNG
   {(char *)"/File/Save As/PNG",       NULL,XMdcFileSelSave,MDC_FRMT_PNG,NULL},
 #endif
